mode(-1);
// Numerical Integration
//   Written by
//   Rakhi.R 
//   IIT Bombay

//Composite Simpson's 1/3rd rule
// This computes I = integral from a to b f(x) dx using this rule
// fa , fb are the values of the function f(x) at a and b respectively
// The interval (a,b) is divided into n panels, each of width h
//n has to be even!
// so h = (b-a)/n
// I is given by
// I = (fa + 2(fx2 + fx4 +....+ fxn-2) + 4(fx1 + fx3 +.....+fxn-1) + fb)*h/3
//If we rename a as x(1), b as x(n+1),(since arrays in sclab start with index of 1)
//I can be written as
//I = (fx1 + 4(fx2 + fx4 +....+ fxn-1) + 2(fx3 +.....+fxn) + fxn+1)*h/3


exec('func.sci'); // execute the function which defines f(x)

temp_sum = 0;
function I = simp3(a,b,n,fa,fb)
    h = (b-a)/n; // interval
    x(1) = a ;
    for i = 1:n-1
        x(i+1) = x(i) + h;  // finds abscissas each separated by h units
        if ~modulo(i+1,2)// if i+1 is divisible by 2
            temp_sum = temp_sum + 4*func(x(i+1)); // for odd terms 
        else
            temp_sum = temp_sum + 2*func(x(i+1)); // for even terms
        // temp_sum is also a vector whose last element gives 
        // 4(fx2 + fx4 +....+ fxn-1) + 2(fx3 +.....+fxn)
        end
    end
    I = (fa + temp_sum($) + fb)*h/3; // finds I as per the formula
      
endfunction