// Euler Method for solving an ODE

// Suppose we wish to solve the following ODE: 
//     y' = y
// with the initial point, 
//     y0 = 1
// The analytical solution for this is:
//     y = y0*e^(x - x0)

clc
clear

// This is our ODE:
function dy = f(y)
    dy = y
endfunction

// Over the following points: 
x = 0:0.5:10;
// We see the difference is: 
h = 0.5
// therefore, 
y(1) = 1 // since indexing begins at 1.

// We implement the Euler method: 
// The Euler method is: 
//     y{n+1} = yn + h*f(xn, yn)

for i = 1:length(x),
    y(i+1) = y(i) + h*f(y(i));
end

// The output, y is: 
// disp(y)

// We compare the answer we have obtained using the analytical solution: 
plot(exp(x'), 'green')
plot(y, 'red')