// Scilab's internal ODE solver

// Suppose we wish to solve the following ODE: 
//     y' = y
// with the initial point, 
//     y0 = 1
// The analytical solution for this is:
//     y = y0*e^(x - x0)

clc
clear

// This is our ODE:
function dy = f(t, y)
    dy = y
endfunction

// Over the following points: 
x = 0:0.5:10;
// Since we will be using Scilab's internal ODE solver, we do not 
// need to specify the step size; Scilab will decide the appropriate 
// step size

// therefore, 
y0 = 1 // here, we are not initializing a vector
x0 = 0

y = ode(y0, x0, x, f);

// We compare the answer we have obtained using the analytical solution: 
plot(exp(x'), 'green')
plot(y, 'magenta')