// Solving a linear equation using Gaussian Elimination:

// Consider the following system of equations: 
//     2x + y -  z =  8 
//    -3x - y + 2z = -11 
//    -2x + y + 2z = -3 

// We can represent the above system in matrix form as follows: 
//     Ax = b
// where,
A = [ 2  1 -1
     -3 -1  2
     -2  1  2]
// and
b = [ 8
     -11
     -3]

// We find the augmented matrix: 
Aug = [A, b]

// We have to perform the following elimination steps to bring 
// the entries below the first pivot to zero:
// R2 --> R2 + (3/2)*R1
// R3 --> R3 + R1

Aug(2, :) = Aug(2, :) + (3/2)*Aug(1, :)
Aug(3, :) = Aug(3, :) + Aug(1, :)

// We now perform the following elimination steps to bring
// the entry below the second pivot to zero: 
// R3 --> R3 - 4*R2

Aug(3, :) = Aug(3, :) - 4*Aug(2, :)

// Therefore, we have the matrices: 
U = Aug(:, 1:3),
c = Aug(:, 4)

// There, we find x, y and z in the reverse order by back substitution:
z = c(3)/U(3, 3)
y = (c(2) - U(2, 3)*z)/U(2, 2)
x = (c(1) - U(1, 3)*z - U(1, 2)*y)/U(1, 1)

// We compare this with the answer that Scilab's internal solver gives:
A\b